/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.message.boards.demo.data.creator.internal;

import com.liferay.message.boards.demo.data.creator.BaseMBCategoryDemoDataCreator;
import com.liferay.message.boards.exception.NoSuchMessageException;
import com.liferay.message.boards.model.MBCategory;
import com.liferay.message.boards.service.MBCategoryLocalService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.service.ServiceContext;

import java.io.IOException;

import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

import org.osgi.service.component.annotations.Reference;

/**
 * @author Sergio González
 */
public abstract class BaseMBCategoryDemoDataCreatorImpl
	implements BaseMBCategoryDemoDataCreator {

	public MBCategory createCategory(
			long userId, long groupId, long categoryId, String name,
			String description)
		throws IOException, PortalException {

		ServiceContext serviceContext = new ServiceContext();

		serviceContext.setAddGroupPermissions(true);
		serviceContext.setAddGuestPermissions(true);
		serviceContext.setScopeGroupId(groupId);

		MBCategory category = mbCategoryLocalService.addCategory(
			userId, categoryId, name, description, serviceContext);

		categoryIds.add(category.getCategoryId());

		return category;
	}

	@Override
	public void delete() throws PortalException {
		for (long categoryId : categoryIds) {
			try {
				mbCategoryLocalService.deleteCategory(categoryId);
			}
			catch (NoSuchMessageException nsme) {
				if (_log.isWarnEnabled()) {
					_log.warn(nsme);
				}
			}

			categoryIds.remove(categoryId);
		}
	}

	@Reference(unbind = "-")
	protected void setMBCategoryLocalService(
		MBCategoryLocalService mbCategoryLocalService) {

		this.mbCategoryLocalService = mbCategoryLocalService;
	}

	protected final List<Long> categoryIds = new CopyOnWriteArrayList<>();
	protected MBCategoryLocalService mbCategoryLocalService;

	private static final Log _log = LogFactoryUtil.getLog(
		BaseMBCategoryDemoDataCreatorImpl.class);

}